import * as i2 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, Component, ChangeDetectionStrategy, Inject } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { RxFor } from '@rx-angular/template/for';
import { RxIf } from '@rx-angular/template/if';
import { RxLet } from '@rx-angular/template/let';
import { RxPush } from '@rx-angular/template/push';
import { DebugComponentComponent } from '@smallstack/common-components';
import { FlagComponent, I18nComponent } from '@smallstack/i18n-components';
import { IconComponent } from '@smallstack/theme-components';
import { TYPE_LOCALES } from '@smallstack/typesystem';
import { RxCollectionService } from '@smallstack/typesystem-client';
import { FormInputContainerComponent } from '@smallstack/widget-core';
import { switchMap, map, BehaviorSubject, combineLatest, firstValueFrom } from 'rxjs';
import { I as InputBaseWidgetComponent } from './smallstack-form-widgets-input-base-widget.component-e4949b87.mjs';
import '@smallstack/utils';

class I18nInputWidgetComponent extends InputBaseWidgetComponent {
    constructor(document) {
        super();
        this.document = document;
        this.rxCollectionService = inject(RxCollectionService);
        this.allLocales$ = this.rxCollectionService.getCollection$(TYPE_LOCALES).pipe(switchMap((localeCollection) => localeCollection.rxCollection.find().$), map((locales) => locales.map((locale) => locale.iso)), map((locales) => [undefined, ...locales]));
        this.defaultLocale$ = this.allLocales$.pipe(map((locales) => locales[0]));
        this.selectedLocale$ = new BehaviorSubject(null);
        this.currentLocale$ = combineLatest([this.selectedLocale$, this.defaultLocale$, this.value$]).pipe(map(([selectedLocale, defaultLocale, value]) => {
            if (selectedLocale !== null)
                return selectedLocale;
            if (value === undefined)
                return defaultLocale;
            if (value.find((t) => t.locale === selectedLocale))
                return selectedLocale;
            if (value.find((t) => t.locale === defaultLocale))
                return defaultLocale;
            if (value.find((t) => t.locale === undefined))
                return undefined;
            if (value instanceof Array && value.length > 0)
                return value[0].locale;
            return defaultLocale;
        }));
        this.currentValue$ = combineLatest([this.currentLocale$, this.value$]).pipe(map(([locale, value]) => {
            if (value === undefined)
                return undefined;
            const translation = value.find((t) => t.locale === locale);
            return translation?.value;
        }));
        this.textarea$ = this.schema$.pipe(map((schema) => {
            return schema && schema["x-schema-form"]?.textarea === true;
        }));
    }
    setCurrentLocale(locale) {
        this.selectedLocale$.next(locale);
        this.document.activeElement.blur();
    }
    async setTranslation(value) {
        let translation = await firstValueFrom(this.value$);
        if (translation === undefined)
            translation = [];
        const locale = await firstValueFrom(this.currentLocale$);
        const existingTranslation = translation.find((t) => t.locale === locale);
        if (existingTranslation === undefined)
            translation.push({ locale, value });
        else
            existingTranslation.value = value;
        await this.setValue(translation);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: I18nInputWidgetComponent, deps: [{ token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: I18nInputWidgetComponent, isStandalone: true, selector: "smallstack-i18n-input-widget", usesInheritance: true, ngImport: i0, template: "<ng-container *rxLet=\"path$; let path\">\n  <smallstack-form-input-container\n    [options]=\"options$ | push\"\n    [schema]=\"schema$ | push\"\n    [path]=\"path\"\n    [validationErrorText$]=\"validationErrorText$\"\n    attr.data-test=\"schema-form-widget-i18n-{{ path }}\"\n  >\n    <div class=\"join w-full\">\n      <div class=\"dropdown join-item\">\n        <button class=\"btn h-full btn-secondary border input-bordered rounded-r-none\">\n          <ng-container *rxLet=\"currentLocale$; let locale\">\n            <ng-container *ngIf=\"locale; else defaultLocaleIcon\">\n              <smallstack-flag [locale]=\"locale\" class=\"rounded\"></smallstack-flag>\n            </ng-container>\n            <ng-template #defaultLocaleIcon>\n              <smallstack-icon\n                name=\"translation\"\n                size=\"19\"\n                theme=\"fluency-systems-regular\"\n                themeColor=\"daisyTheme.secondary.textColor\"\n              ></smallstack-icon>\n            </ng-template>\n          </ng-container>\n        </button>\n        <div class=\"menu dropdown-content z-[1] p-2 shadow bg-base-100 rounded-box flex flex-col gap-1\">\n          <button\n            *rxFor=\"let locale of allLocales$\"\n            (click)=\"setCurrentLocale(locale)\"\n            class=\"btn w-full btn-secondary\"\n          >\n            <div class=\"flex flex-row gap-1 w-full justify-start items-center whitespace-nowrap\">\n              <ng-container *ngIf=\"locale; else notTranslated\">\n                <smallstack-flag [locale]=\"locale\"></smallstack-flag> <span>{{ locale }}</span>\n              </ng-container>\n              <ng-template #notTranslated>\n                <smallstack-icon\n                  name=\"translation\"\n                  size=\"19\"\n                  theme=\"fluency-systems-regular\"\n                  themeColor=\"daisyTheme.secondary.textColor\"\n                ></smallstack-icon>\n                <span>Standard</span>\n              </ng-template>\n            </div>\n          </button>\n        </div>\n      </div>\n      <textarea\n        *rxIf=\"textarea$; else showInput\"\n        tabindex=\"0\"\n        class=\"textarea textarea-bordered w-full join-item h-32\"\n        [required]=\"required$ | push\"\n        [ngModel]=\"currentValue$ | push\"\n        (ngModelChange)=\"setTranslation($event); validateOnChange()\"\n        (blur)=\"validateOnBlur()\"\n        [placeholder]=\"placeholder$ | push\"\n        attr.data-test=\"schema-form-widget-i18n-{{ path }}-input\"\n        (keyup.enter)=\"formService.submit()\"\n        [ngClass]=\"{ 'input-error': (validationErrorText$ | push) !== undefined }\"\n      ></textarea>\n      <ng-template #showInput>\n        <input\n          tabindex=\"0\"\n          type=\"text\"\n          class=\"input input-bordered w-full join-item\"\n          [required]=\"required$ | push\"\n          [ngModel]=\"currentValue$ | push\"\n          (ngModelChange)=\"setTranslation($event); validateOnChange()\"\n          (blur)=\"validateOnBlur()\"\n          [placeholder]=\"placeholder$ | push\"\n          attr.data-test=\"schema-form-widget-i18n-{{ path }}-input\"\n          (keyup.enter)=\"formService.submit()\"\n          [ngClass]=\"{ 'input-error': (validationErrorText$ | push) !== undefined }\"\n        />\n      </ng-template>\n    </div>\n  </smallstack-form-input-container>\n</ng-container>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: FlagComponent, selector: "smallstack-flag", inputs: ["language", "country", "locale"] }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "dynamic", "badgeColor"], outputs: ["iconError"] }, { kind: "component", type: FormInputContainerComponent, selector: "smallstack-form-input-container", inputs: ["validationErrorText$", "options", "schema", "path"] }, { kind: "pipe", type: RxPush, name: "push" }, { kind: "directive", type: RxFor, selector: "[rxFor][rxForOf]", inputs: ["rxForOf", "rxForTemplate", "rxForStrategy", "rxForParent", "rxForPatchZone", "rxForTrackBy", "rxForRenderCallback"] }, { kind: "directive", type: RxIf, selector: "[rxIf]", inputs: ["rxIf", "rxIfStrategy", "rxIfElse", "rxIfThen", "rxIfSuspense", "rxIfComplete", "rxIfError", "rxIfContextTrigger", "rxIfNextTrigger", "rxIfSuspenseTrigger", "rxIfErrorTrigger", "rxIfCompleteTrigger", "rxIfParent", "rxIfPatchZone", "rxIfRenderCallback"] }, { kind: "directive", type: RxLet, selector: "[rxLet]", inputs: ["rxLet", "rxLetStrategy", "rxLetComplete", "rxLetError", "rxLetSuspense", "rxLetContextTrigger", "rxLetCompleteTrigger", "rxLetErrorTrigger", "rxLetSuspenseTrigger", "rxLetNextTrigger", "rxLetRenderCallback", "rxLetParent", "rxLetPatchZone"], outputs: ["rendered"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: I18nInputWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-i18n-input-widget", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        CommonModule,
                        FlagComponent,
                        IconComponent,
                        I18nComponent,
                        FormInputContainerComponent,
                        RxPush,
                        RxFor,
                        RxIf,
                        RxLet,
                        FormsModule,
                        DebugComponentComponent
                    ], template: "<ng-container *rxLet=\"path$; let path\">\n  <smallstack-form-input-container\n    [options]=\"options$ | push\"\n    [schema]=\"schema$ | push\"\n    [path]=\"path\"\n    [validationErrorText$]=\"validationErrorText$\"\n    attr.data-test=\"schema-form-widget-i18n-{{ path }}\"\n  >\n    <div class=\"join w-full\">\n      <div class=\"dropdown join-item\">\n        <button class=\"btn h-full btn-secondary border input-bordered rounded-r-none\">\n          <ng-container *rxLet=\"currentLocale$; let locale\">\n            <ng-container *ngIf=\"locale; else defaultLocaleIcon\">\n              <smallstack-flag [locale]=\"locale\" class=\"rounded\"></smallstack-flag>\n            </ng-container>\n            <ng-template #defaultLocaleIcon>\n              <smallstack-icon\n                name=\"translation\"\n                size=\"19\"\n                theme=\"fluency-systems-regular\"\n                themeColor=\"daisyTheme.secondary.textColor\"\n              ></smallstack-icon>\n            </ng-template>\n          </ng-container>\n        </button>\n        <div class=\"menu dropdown-content z-[1] p-2 shadow bg-base-100 rounded-box flex flex-col gap-1\">\n          <button\n            *rxFor=\"let locale of allLocales$\"\n            (click)=\"setCurrentLocale(locale)\"\n            class=\"btn w-full btn-secondary\"\n          >\n            <div class=\"flex flex-row gap-1 w-full justify-start items-center whitespace-nowrap\">\n              <ng-container *ngIf=\"locale; else notTranslated\">\n                <smallstack-flag [locale]=\"locale\"></smallstack-flag> <span>{{ locale }}</span>\n              </ng-container>\n              <ng-template #notTranslated>\n                <smallstack-icon\n                  name=\"translation\"\n                  size=\"19\"\n                  theme=\"fluency-systems-regular\"\n                  themeColor=\"daisyTheme.secondary.textColor\"\n                ></smallstack-icon>\n                <span>Standard</span>\n              </ng-template>\n            </div>\n          </button>\n        </div>\n      </div>\n      <textarea\n        *rxIf=\"textarea$; else showInput\"\n        tabindex=\"0\"\n        class=\"textarea textarea-bordered w-full join-item h-32\"\n        [required]=\"required$ | push\"\n        [ngModel]=\"currentValue$ | push\"\n        (ngModelChange)=\"setTranslation($event); validateOnChange()\"\n        (blur)=\"validateOnBlur()\"\n        [placeholder]=\"placeholder$ | push\"\n        attr.data-test=\"schema-form-widget-i18n-{{ path }}-input\"\n        (keyup.enter)=\"formService.submit()\"\n        [ngClass]=\"{ 'input-error': (validationErrorText$ | push) !== undefined }\"\n      ></textarea>\n      <ng-template #showInput>\n        <input\n          tabindex=\"0\"\n          type=\"text\"\n          class=\"input input-bordered w-full join-item\"\n          [required]=\"required$ | push\"\n          [ngModel]=\"currentValue$ | push\"\n          (ngModelChange)=\"setTranslation($event); validateOnChange()\"\n          (blur)=\"validateOnBlur()\"\n          [placeholder]=\"placeholder$ | push\"\n          attr.data-test=\"schema-form-widget-i18n-{{ path }}-input\"\n          (keyup.enter)=\"formService.submit()\"\n          [ngClass]=\"{ 'input-error': (validationErrorText$ | push) !== undefined }\"\n        />\n      </ng-template>\n    </div>\n  </smallstack-form-input-container>\n</ng-container>\n" }]
        }], ctorParameters: function () { return [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; } });

export { I18nInputWidgetComponent };
//# sourceMappingURL=smallstack-form-widgets-i18n-input-widget.component-27a9a4f6.mjs.map
